@@ -31,40 +31,53 @@
 
 class Configuration_Dialog : public QTabDialog {
     Q_OBJECT
-friend class Configuration;
-public: 
-	Configuration_Dialog(QWidget *parent, const char *name=0);
-	~Configuration_Dialog();
+    friend class Configuration;
+public:
+    Configuration_Dialog(QWidget *parent, const char *name=0);
+    ~Configuration_Dialog();
 private:
     QLineEdit *db_host_line, *db_database_line, *db_user_line, *db_pass_line;
-#ifdef EMBEDDED
+    #ifdef EMBEDDED
+
     QLineEdit *embedded_basedir_line, *embedded_language_line;
-#endif /* EMBEDDED */
-    QLineEdit *burnCD_line, *k3b_line; 
-    QLabel *l1, *l2;
-#ifdef HAVE_MIXXX
+    #endif /* EMBEDDED */
+
+    QLineEdit *burnCD_line, *k3b_line;
+    QLabel *play_label, *pause_label, *stop_label, *next_label, *prev_label, *enqueue_label ;
+    QLabel *preplay_label, *prepause_label, *prestop_label, *prenext_label, *preprev_label, *preenqueue_label;
+
+    #ifdef HAVE_MIXXX
+
     QLabel *lmixxxhost, *lmixxxport;
     QLineEdit *mixxxhost_line, *mixxxport_line;
     QCheckBox *enableRegularPlayer, *enableMixxxPlayer;
-#endif /* HAVE_MIXXX */
-#ifdef HAVE_LIBMUSICBRAINZ
+    #endif /* HAVE_MIXXX */
+    #ifdef HAVE_LIBMUSICBRAINZ
+
     QLineEdit *musicBrainzServer_line, *musicBrainzPort_line;
-#endif /* HAVE_LIBMUSICBRAINZ */
+    #endif /* HAVE_LIBMUSICBRAINZ */
+
     QLineEdit *smbKeywords_line, *nfsKeywords_line;
-    QComboBox *play_line, *enqueue_line, *comboSortingMode;
+    QComboBox *play_line, *pause_line, *stop_line, *next_line, *prev_line, *enqueue_line;
+    QComboBox *preplay_line, *prepause_line, *prestop_line, *prenext_line, *preprev_line, *preenqueue_line;
+    QComboBox *comboSortingMode;
     QCheckBox *readv2check, *writev2check, *autocheck, *hidecheck, *hddcheck;
     QCheckBox *smbcheck, *nfscheck;
     QCheckBox *showtooltip, *maxwidthmode, *guirestore;
     QLineEdit *customrename_line;
-#ifdef HAVE_MEXTRAS
+    #ifdef HAVE_MEXTRAS
+
     QCheckBox *mextras_bgnd;
 #endif /* HAVE_MEXTRAS */
-    QCheckBox *checkartist, *checkcover, *checklyrics, *checkalbum;
+    QCheckBox *checkartist, *checkcover, *checklyrics, *checksyncedlyrics, *checkalbum;
     QCheckBox *checktracks, *checkbiography, *checkyears;
     QListView *hddlist;
     QSpinBox *mexspinbox;
     QPushButton *hddedit, *hddremove;
     QCheckBox *comboSortingAuto;
+
+    void generatePlayerControlLine (QLabel*, QComboBox*, QString, QString);
+
 private slots:
     void slot_clickenableRegularPlayer();
     void slot_clickenableMixxxPlayer();
