@@ -24,14 +24,13 @@
 // # initialize listing gui
 // ##############################################
 ExtendedListView::ExtendedListView(QWidget *parent, const char *name)
-  : QListView(parent, name)
-{}
+: QListView(parent, name) {}
 
-QDragObject *ExtendedListView::dragObject()
-{
+QDragObject *ExtendedListView::dragObject() {
     QStrList urls;
     for (QListViewItem *item = firstChild(); item != 0; item = item->nextSibling()) {
-        if (item->isSelected() && dynamic_cast<LVI_Track*>(item)->getIsAvailable()) {
+        if (item->isSelected() && dynamic_cast<LVI_Track*>(item)->
+                getIsAvailable()) {
             QString filename = dynamic_cast<LVI_Track*>(item)->getPath() + "/" + dynamic_cast<LVI_Track*>(item)->getFilename();
             urls.append(QUriDrag::localFileToUri(filename.stripWhiteSpace()));
         }
