@@ -27,8 +27,7 @@ class QRadioButton;
 class QTextBrowser;
 class QStatusBar;
 
-class FindDialog : public QDialog
-{
+class FindDialog : public QDialog {
     Q_OBJECT
 
 public:
