@@ -1,8 +1,8 @@
 /****************************************************************************
 ** GUI_Playlist meta object code from reading C++ file 'gui_playlist.h'
 **
-** Created: Mon Nov 14 16:03:06 2005
-**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.4   edited Jan 21 18:14 $)
+** Created: Sat Jan 6 23:56:09 2007
+**      by: The Qt MOC ($Id: qt/moc_yacc.cpp   3.3.6   edited Mar 8 17:43 $)
 **
 ** WARNING! All changes made in this file will be lost!
 *****************************************************************************/
@@ -14,7 +14,7 @@
 
 #include <private/qucomextra_p.h>
 #if !defined(Q_MOC_OUTPUT_REVISION) || (Q_MOC_OUTPUT_REVISION != 26)
-#error "This file was generated using the moc from 3.3.4. It"
+#error "This file was generated using the moc from 3.3.6. It"
 #error "cannot be used with the include files from this version of Qt."
 #error "(The moc has changed too much.)"
 #endif
@@ -94,40 +94,45 @@ QMetaObject* GUI_Playlist::staticMetaObject()
     static const QUMethod slot_25 = {"slot_menuRenamePlaylist", 0, 0 };
     static const QUMethod slot_26 = {"slot_menuPlayPlaylistTracks", 0, 0 };
     static const QUMethod slot_27 = {"slot_menuEnqueuePlaylistTracks", 0, 0 };
-    static const QUMethod slot_28 = {"slot_mixxxLoadAtChannel1", 0, 0 };
-    static const QUMethod slot_29 = {"slot_mixxxLoadAtChannel2", 0, 0 };
-    static const QUMethod slot_30 = {"slot_mixxxLoadAndPlayAtChannel1", 0, 0 };
-    static const QUMethod slot_31 = {"slot_mixxxLoadAndPlayAtChannel2", 0, 0 };
-    static const QUMethod slot_32 = {"slot_mixxxEnqueueTracksAtChannel1", 0, 0 };
-    static const QUMethod slot_33 = {"slot_mixxxEnqueueTracksAtChannel2", 0, 0 };
-    static const QUMethod slot_34 = {"slot_menuEnqueuePlaylistAtChannel1", 0, 0 };
-    static const QUMethod slot_35 = {"slot_menuEnqueuePlaylistAtChannel2", 0, 0 };
-    static const QUParameter param_slot_36[] = {
+    static const QUMethod slot_28 = {"slot_menuPrelistenPlaylistTracks", 0, 0 };
+    static const QUMethod slot_29 = {"slot_mixxxLoadAtChannel1", 0, 0 };
+    static const QUMethod slot_30 = {"slot_mixxxLoadAtChannel2", 0, 0 };
+    static const QUMethod slot_31 = {"slot_mixxxLoadAndPlayAtChannel1", 0, 0 };
+    static const QUMethod slot_32 = {"slot_mixxxLoadAndPlayAtChannel2", 0, 0 };
+    static const QUMethod slot_33 = {"slot_mixxxEnqueueTracksAtChannel1", 0, 0 };
+    static const QUMethod slot_34 = {"slot_mixxxEnqueueTracksAtChannel2", 0, 0 };
+    static const QUMethod slot_35 = {"slot_menuEnqueuePlaylistAtChannel1", 0, 0 };
+    static const QUMethod slot_36 = {"slot_menuEnqueuePlaylistAtChannel2", 0, 0 };
+    static const QUParameter param_slot_37[] = {
 	{ 0, &static_QUType_ptr, "QListViewItem", QUParameter::In }
     };
-    static const QUMethod slot_36 = {"slot_playlistSelectionChanged", 1, param_slot_36 };
-    static const QUMethod slot_37 = {"slot_trackSelectionChanged", 0, 0 };
-    static const QUParameter param_slot_38[] = {
+    static const QUMethod slot_37 = {"slot_playlistSelectionChanged", 1, param_slot_37 };
+    static const QUMethod slot_38 = {"slot_trackSelectionChanged", 0, 0 };
+    static const QUParameter param_slot_39[] = {
 	{ 0, &static_QUType_ptr, "QWidget", QUParameter::In }
     };
-    static const QUMethod slot_38 = {"slot_tabChange", 1, param_slot_38 };
-    static const QUParameter param_slot_39[] = {
-	{ "lvi", &static_QUType_ptr, "QListViewItem", QUParameter::In }
-    };
-    static const QUMethod slot_39 = {"slot_playlistDoubleClicked", 1, param_slot_39 };
+    static const QUMethod slot_39 = {"slot_tabChange", 1, param_slot_39 };
     static const QUParameter param_slot_40[] = {
 	{ "lvi", &static_QUType_ptr, "QListViewItem", QUParameter::In }
     };
-    static const QUMethod slot_40 = {"slot_playlistTrackDoubleClicked", 1, param_slot_40 };
-    static const QUMethod slot_41 = {"slot_ClickLyrics", 0, 0 };
-    static const QUMethod slot_42 = {"slot_ClickReview", 0, 0 };
-    static const QUMethod slot_43 = {"slot_ClickTracks", 0, 0 };
-    static const QUMethod slot_44 = {"slot_ClickBiography", 0, 0 };
-    static const QUMethod slot_45 = {"slot_ClickMexlog", 0, 0 };
-    static const QUParameter param_slot_46[] = {
+    static const QUMethod slot_40 = {"slot_playlistDoubleClicked", 1, param_slot_40 };
+    static const QUParameter param_slot_41[] = {
+	{ "lvi", &static_QUType_ptr, "QListViewItem", QUParameter::In }
+    };
+    static const QUMethod slot_41 = {"slot_playlistTrackDoubleClicked", 1, param_slot_41 };
+    static const QUMethod slot_42 = {"slot_ClickLyrics", 0, 0 };
+    static const QUMethod slot_43 = {"slot_ClickReview", 0, 0 };
+    static const QUMethod slot_44 = {"slot_ClickTracks", 0, 0 };
+    static const QUMethod slot_45 = {"slot_ClickBiography", 0, 0 };
+    static const QUMethod slot_46 = {"slot_ClickMexlog", 0, 0 };
+    static const QUParameter param_slot_47[] = {
+	{ 0, &static_QUType_int, 0, QUParameter::In }
+    };
+    static const QUMethod slot_47 = {"slot_changeLyricsRadio", 1, param_slot_47 };
+    static const QUParameter param_slot_48[] = {
 	{ "lst", &static_QUType_ptr, "QPtrList<QNetworkOperation>", QUParameter::In }
     };
-    static const QUMethod slot_46 = {"slot_startedNextCopy", 1, param_slot_46 };
+    static const QUMethod slot_48 = {"slot_startedNextCopy", 1, param_slot_48 };
     static const QMetaData slot_tbl[] = {
 	{ "slot_setConnectionState(bool)", &slot_0, QMetaData::Public },
 	{ "slot_newButton()", &slot_1, QMetaData::Private },
@@ -157,29 +162,31 @@ QMetaObject* GUI_Playlist::staticMetaObject()
 	{ "slot_menuRenamePlaylist()", &slot_25, QMetaData::Private },
 	{ "slot_menuPlayPlaylistTracks()", &slot_26, QMetaData::Private },
 	{ "slot_menuEnqueuePlaylistTracks()", &slot_27, QMetaData::Private },
-	{ "slot_mixxxLoadAtChannel1()", &slot_28, QMetaData::Private },
-	{ "slot_mixxxLoadAtChannel2()", &slot_29, QMetaData::Private },
-	{ "slot_mixxxLoadAndPlayAtChannel1()", &slot_30, QMetaData::Private },
-	{ "slot_mixxxLoadAndPlayAtChannel2()", &slot_31, QMetaData::Private },
-	{ "slot_mixxxEnqueueTracksAtChannel1()", &slot_32, QMetaData::Private },
-	{ "slot_mixxxEnqueueTracksAtChannel2()", &slot_33, QMetaData::Private },
-	{ "slot_menuEnqueuePlaylistAtChannel1()", &slot_34, QMetaData::Private },
-	{ "slot_menuEnqueuePlaylistAtChannel2()", &slot_35, QMetaData::Private },
-	{ "slot_playlistSelectionChanged(QListViewItem*)", &slot_36, QMetaData::Private },
-	{ "slot_trackSelectionChanged()", &slot_37, QMetaData::Private },
-	{ "slot_tabChange(QWidget*)", &slot_38, QMetaData::Private },
-	{ "slot_playlistDoubleClicked(QListViewItem*)", &slot_39, QMetaData::Private },
-	{ "slot_playlistTrackDoubleClicked(QListViewItem*)", &slot_40, QMetaData::Private },
-	{ "slot_ClickLyrics()", &slot_41, QMetaData::Private },
-	{ "slot_ClickReview()", &slot_42, QMetaData::Private },
-	{ "slot_ClickTracks()", &slot_43, QMetaData::Private },
-	{ "slot_ClickBiography()", &slot_44, QMetaData::Private },
-	{ "slot_ClickMexlog()", &slot_45, QMetaData::Private },
-	{ "slot_startedNextCopy(const QPtrList<QNetworkOperation>&)", &slot_46, QMetaData::Private }
+	{ "slot_menuPrelistenPlaylistTracks()", &slot_28, QMetaData::Private },
+	{ "slot_mixxxLoadAtChannel1()", &slot_29, QMetaData::Private },
+	{ "slot_mixxxLoadAtChannel2()", &slot_30, QMetaData::Private },
+	{ "slot_mixxxLoadAndPlayAtChannel1()", &slot_31, QMetaData::Private },
+	{ "slot_mixxxLoadAndPlayAtChannel2()", &slot_32, QMetaData::Private },
+	{ "slot_mixxxEnqueueTracksAtChannel1()", &slot_33, QMetaData::Private },
+	{ "slot_mixxxEnqueueTracksAtChannel2()", &slot_34, QMetaData::Private },
+	{ "slot_menuEnqueuePlaylistAtChannel1()", &slot_35, QMetaData::Private },
+	{ "slot_menuEnqueuePlaylistAtChannel2()", &slot_36, QMetaData::Private },
+	{ "slot_playlistSelectionChanged(QListViewItem*)", &slot_37, QMetaData::Private },
+	{ "slot_trackSelectionChanged()", &slot_38, QMetaData::Private },
+	{ "slot_tabChange(QWidget*)", &slot_39, QMetaData::Private },
+	{ "slot_playlistDoubleClicked(QListViewItem*)", &slot_40, QMetaData::Private },
+	{ "slot_playlistTrackDoubleClicked(QListViewItem*)", &slot_41, QMetaData::Private },
+	{ "slot_ClickLyrics()", &slot_42, QMetaData::Private },
+	{ "slot_ClickReview()", &slot_43, QMetaData::Private },
+	{ "slot_ClickTracks()", &slot_44, QMetaData::Private },
+	{ "slot_ClickBiography()", &slot_45, QMetaData::Private },
+	{ "slot_ClickMexlog()", &slot_46, QMetaData::Private },
+	{ "slot_changeLyricsRadio(int)", &slot_47, QMetaData::Private },
+	{ "slot_startedNextCopy(const QPtrList<QNetworkOperation>&)", &slot_48, QMetaData::Private }
     };
     metaObj = QMetaObject::new_metaobject(
 	"GUI_Playlist", parentObject,
-	slot_tbl, 47,
+	slot_tbl, 49,
 	0, 0,
 #ifndef QT_NO_PROPERTIES
 	0, 0,
@@ -228,25 +235,27 @@ bool GUI_Playlist::qt_invoke( int _id, QUObject* _o )
     case 25: slot_menuRenamePlaylist(); break;
     case 26: slot_menuPlayPlaylistTracks(); break;
     case 27: slot_menuEnqueuePlaylistTracks(); break;
-    case 28: slot_mixxxLoadAtChannel1(); break;
-    case 29: slot_mixxxLoadAtChannel2(); break;
-    case 30: slot_mixxxLoadAndPlayAtChannel1(); break;
-    case 31: slot_mixxxLoadAndPlayAtChannel2(); break;
-    case 32: slot_mixxxEnqueueTracksAtChannel1(); break;
-    case 33: slot_mixxxEnqueueTracksAtChannel2(); break;
-    case 34: slot_menuEnqueuePlaylistAtChannel1(); break;
-    case 35: slot_menuEnqueuePlaylistAtChannel2(); break;
-    case 36: slot_playlistSelectionChanged((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
-    case 37: slot_trackSelectionChanged(); break;
-    case 38: slot_tabChange((QWidget*)static_QUType_ptr.get(_o+1)); break;
-    case 39: slot_playlistDoubleClicked((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
-    case 40: slot_playlistTrackDoubleClicked((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
-    case 41: slot_ClickLyrics(); break;
-    case 42: slot_ClickReview(); break;
-    case 43: slot_ClickTracks(); break;
-    case 44: slot_ClickBiography(); break;
-    case 45: slot_ClickMexlog(); break;
-    case 46: slot_startedNextCopy((const QPtrList<QNetworkOperation>&)*((const QPtrList<QNetworkOperation>*)static_QUType_ptr.get(_o+1))); break;
+    case 28: slot_menuPrelistenPlaylistTracks(); break;
+    case 29: slot_mixxxLoadAtChannel1(); break;
+    case 30: slot_mixxxLoadAtChannel2(); break;
+    case 31: slot_mixxxLoadAndPlayAtChannel1(); break;
+    case 32: slot_mixxxLoadAndPlayAtChannel2(); break;
+    case 33: slot_mixxxEnqueueTracksAtChannel1(); break;
+    case 34: slot_mixxxEnqueueTracksAtChannel2(); break;
+    case 35: slot_menuEnqueuePlaylistAtChannel1(); break;
+    case 36: slot_menuEnqueuePlaylistAtChannel2(); break;
+    case 37: slot_playlistSelectionChanged((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
+    case 38: slot_trackSelectionChanged(); break;
+    case 39: slot_tabChange((QWidget*)static_QUType_ptr.get(_o+1)); break;
+    case 40: slot_playlistDoubleClicked((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
+    case 41: slot_playlistTrackDoubleClicked((QListViewItem*)static_QUType_ptr.get(_o+1)); break;
+    case 42: slot_ClickLyrics(); break;
+    case 43: slot_ClickReview(); break;
+    case 44: slot_ClickTracks(); break;
+    case 45: slot_ClickBiography(); break;
+    case 46: slot_ClickMexlog(); break;
+    case 47: slot_changeLyricsRadio((int)static_QUType_int.get(_o+1)); break;
+    case 48: slot_startedNextCopy((const QPtrList<QNetworkOperation>&)*((const QPtrList<QNetworkOperation>*)static_QUType_ptr.get(_o+1))); break;
     default:
 	return QTabWidget::qt_invoke( _id, _o );
     }
