@@ -1,5 +1,5 @@
 /****************************************************************************
-** $Id: helpviewer.h,v 1.6 2005/08/04 23:48:27 mkalkbrenner Exp $
+** $Id: helpviewer.h,v 1.7 2006/02/01 07:47:52 mkalkbrenner Exp $
 **
 ** Copyright (C) 1992-2000 Trolltech AS.  All rights reserved.
 **
@@ -25,18 +25,18 @@ class QComboBox;
 class QPopupMenu;
 
 
-class TextBrowser : public QTextBrowser
-{
-  Q_OBJECT
+class TextBrowser : public QTextBrowser {
+    Q_OBJECT
 public:
-  TextBrowser ( QWidget * parent = 0, const char * name = 0 ): QTextBrowser( parent, name ) {;}
+TextBrowser ( QWidget * parent = 0, const char * name = 0 ): QTextBrowser( parent, name ) {
+        ;
+    }
 public slots:
     void setSource ( const QString & name );
-}; 
+};
 
 
-class HelpWindow : public QMainWindow
-{
+class HelpWindow : public QMainWindow {
     Q_OBJECT
 public:
     HelpWindow( const QString& home_,  const QString& path, QWidget* parent = 0, const char *name=0 );
