@@ -25,17 +25,19 @@
 #include "lvi_cddrive.h"
 
 class Job_AppendCDROMToDatabase : public JobBaseTagManipulation  {
-public: 
-	Job_AppendCDROMToDatabase(LVI_CDDrive *_drive);
-	
-	int type() { return JOB_APPEND_CDROM_TO_DATABASE; }
+public:
+    Job_AppendCDROMToDatabase(LVI_CDDrive *_drive);
 
-	void run();
-		
-	~Job_AppendCDROMToDatabase();
+    int type() {
+        return JOB_APPEND_CDROM_TO_DATABASE;
+    }
+
+    void run();
+
+    ~Job_AppendCDROMToDatabase();
 
 private:
-	LVI_CDDrive *drive;
+    LVI_CDDrive *drive;
 };
 
 #endif
