@@ -25,17 +25,19 @@
 #include "lvi_nfsexport.h"
 
 class Job_AppendNFSToDatabase : public JobBaseTagManipulation  {
- public: 
-  Job_AppendNFSToDatabase(LVI_NFSExport *_Export);
+public:
+    Job_AppendNFSToDatabase(LVI_NFSExport *_Export);
 
-  int type() { return JOB_APPEND_NFS_TO_DATABASE; }
+    int type() {
+        return JOB_APPEND_NFS_TO_DATABASE;
+    }
 
-  void run();
+    void run();
 
-  ~Job_AppendNFSToDatabase();
+    ~Job_AppendNFSToDatabase();
 
- private:
-  LVI_NFSExport *Export;
+private:
+    LVI_NFSExport *Export;
 };
 
 #endif
