@@ -25,17 +25,19 @@
 #include "lvi_smbshare.h"
 
 class Job_AppendSMBToDatabase : public JobBaseTagManipulation  {
- public: 
-  Job_AppendSMBToDatabase(LVI_SMBShare *_share);
+public:
+    Job_AppendSMBToDatabase(LVI_SMBShare *_share);
 
-  int type() { return JOB_APPEND_SMB_TO_DATABASE; }
+    int type() {
+        return JOB_APPEND_SMB_TO_DATABASE;
+    }
 
-  void run();
+    void run();
 
-  ~Job_AppendSMBToDatabase();
+    ~Job_AppendSMBToDatabase();
 
- private:
-  LVI_SMBShare *share;
+private:
+    LVI_SMBShare *share;
 };
 
 #endif
