@@ -8,15 +8,23 @@
 class Job_CallMusicextras : public JobBase {
 
 public:
-	Job_CallMusicextras( TRACK _track, bool _refresh );
+    Job_CallMusicextras( TRACK _track, bool _refresh );
 
-	int type() { return JOB_CALL_MUSICEXTRAS; }
+    int type() {
+        return JOB_CALL_MUSICEXTRAS;
+    }
 
-	static void JobSleep ( unsigned long msecs ) {msleep( msecs);}
-	void run();
-	void safeTerminate() { terminated=true; if (mw) mw->safeTerminate();}   // set safe termination flag
- 	
-	~Job_CallMusicextras();
+    static void JobSleep ( unsigned long msecs ) {
+        msleep( msecs);
+    }
+    void run();
+    void safeTerminate() {
+        terminated=true;
+        if (mw)
+            mw->safeTerminate();
+    }   // set safe termination flag
+
+    ~Job_CallMusicextras();
 
 private:
     TRACK track;
