@@ -25,19 +25,21 @@
 #include "lvi_cddrive.h"
 
 class Job_ComputeCDROMID : public JobBase  {
-public: 
-	Job_ComputeCDROMID(LVI_CDDrive *_drive);
-	
-	int type() { return JOB_COMPUTE_CDROM_ID; }
+public:
+    Job_ComputeCDROMID(LVI_CDDrive *_drive);
 
-	void run();
-		
-	~Job_ComputeCDROMID();
+    int type() {
+        return JOB_COMPUTE_CDROM_ID;
+    }
+
+    void run();
+
+    ~Job_ComputeCDROMID();
 
 private:
-	LVI_CDDrive *drive;
+    LVI_CDDrive *drive;
 
-	unsigned CRC32(QString);
+    unsigned CRC32(QString);
 };
 
 #endif
