@@ -1,5 +1,5 @@
 /***************************************************************************
-            	    job_connecttodatabase.h  -  description
+                    job_connecttodatabase.h  -  description
                              -------------------
     begin                : Thu May 3 2001
     copyright            : (C) 2001 by Holger Sattel
@@ -23,17 +23,19 @@
 #include "jobbase.h"
 
 class Job_ConnectToDatabase : public JobBase  {
-public: 
-	Job_ConnectToDatabase(QString _host, QString _db, QString _user, QString _pass);
-	
-	int type() { return JOB_CONNECT_TO_DATABASE; }
+public:
+    Job_ConnectToDatabase(QString _host, QString _db, QString _user, QString _pass);
 
-	void run();
-		
-	~Job_ConnectToDatabase();
+    int type() {
+        return JOB_CONNECT_TO_DATABASE;
+    }
+
+    void run();
+
+    ~Job_ConnectToDatabase();
 
 private:
-	QString host, db, user, pass;
+    QString host, db, user, pass;
 };
 
 #endif
