@@ -6,17 +6,19 @@
 #include "jobbase.h"
 
 class Job_ConnectToMixxx : public JobBase  {
-public: 
-	Job_ConnectToMixxx(QString _host, int port);
-	
-	int type() { return JOB_CONNECT_TO_MIXXX; }
+public:
+    Job_ConnectToMixxx(QString _host, int port);
 
-	void run();
-		
-	~Job_ConnectToMixxx();
+    int type() {
+        return JOB_CONNECT_TO_MIXXX;
+    }
+
+    void run();
+
+    ~Job_ConnectToMixxx();
 
 private:
-	QString host;
+    QString host;
     int port;
 };
 
