@@ -24,13 +24,15 @@
 
 class Job_CountData : public JobBase  {
 public:
- Job_CountData();
-    
-  int type() { return JOB_COUNT_DATA; }
+    Job_CountData();
+
+    int type() {
+        return JOB_COUNT_DATA;
+    }
 
     void run();
-       
-  ~Job_CountData();
+
+    ~Job_CountData();
 
 };
 
