@@ -25,17 +25,19 @@
 #include "lvi_medium.h"
 
 class Job_DeleteMediumFromDatabase : public JobBase  {
- public: 
-  Job_DeleteMediumFromDatabase(LVI_Medium *_lvi);
-  
-  int type() { return JOB_DELETE_MEDIUM_FROM_DATABASE; }
-  
-  void run();
-  
-  ~Job_DeleteMediumFromDatabase();
+public:
+    Job_DeleteMediumFromDatabase(LVI_Medium *_lvi);
 
- private:
-  LVI_Medium *lvi;
+    int type() {
+        return JOB_DELETE_MEDIUM_FROM_DATABASE;
+    }
+
+    void run();
+
+    ~Job_DeleteMediumFromDatabase();
+
+private:
+    LVI_Medium *lvi;
 };
 
 #endif
