@@ -23,17 +23,19 @@
 #include "jobbase.h"
 
 class Job_DeleteTrackPhysically : public JobBase  {
- public: 
-  Job_DeleteTrackPhysically(TRACK *_track);
-  
-  int type() { return JOB_DELETE_TRACK_PHYSICALLY; }
-	
-  void run();
+public:
+    Job_DeleteTrackPhysically(TRACK *_track);
 
-  ~Job_DeleteTrackPhysically();
+    int type() {
+        return JOB_DELETE_TRACK_PHYSICALLY;
+    }
 
- private:
-  TRACK *track;
+    void run();
+
+    ~Job_DeleteTrackPhysically();
+
+private:
+    TRACK *track;
 };
 
 #endif
