@@ -21,38 +21,45 @@
 #include "database.h"
 #include "datadispatcher.h"
 
-#ifdef EMBEDDED 
-  #include <mysql.h>
+#ifdef EMBEDDED
+#include <mysql.h>
 #endif
 
 Job_DisconnectFromDatabase::Job_DisconnectFromDatabase() {}
 
-void Job_DisconnectFromDatabase::run()
-{
+void Job_DisconnectFromDatabase::run() {
 
-  if (verbose==8) qWarning( "    >run() tread:%p type:%s HANDLE:%p", this, JOB_CODE[type()], currentThread() );
+    if (verbose==8)
+        qWarning( "    >run() tread:%p type:%s HANDLE:%p", this, JOB_CODE[type()], currentThread() );
 
-#ifdef EMBEDDED 
-  mysql_thread_init(); 
-#endif
-  database->lock();
-  app->lock();
+    #ifdef EMBEDDED
 
-  database->disconnect();
+    mysql_thread_init();
+    #endif
 
-  app->unlock();
-  database->unlock();
-  
-  jobman->lock();
-  jobman->jobDone(this);
-  jobman->unlock();
-#ifdef EMBEDDED 
-  mysql_thread_end(); 
-#endif
+    database->lock()
+    ;
+    app->lock()
+    ;
 
-  if (verbose==8) qWarning( "    >exit() thread:%p type:%s HANDLE: %p", this, JOB_CODE[type()], currentThread() );
+    database->disconnect();
 
-  exit();
+    app->unlock();
+    database->unlock();
+
+    jobman->lock()
+    ;
+    jobman->jobDone(this);
+    jobman->unlock();
+    #ifdef EMBEDDED
+
+    mysql_thread_end();
+    #endif
+
+    if (verbose==8)
+        qWarning( "    >exit() thread:%p type:%s HANDLE: %p", this, JOB_CODE[type()], currentThread() );
+
+    exit();
 }
 
 Job_DisconnectFromDatabase::~Job_DisconnectFromDatabase() {}
