@@ -23,14 +23,16 @@
 #include "jobbase.h"
 
 class Job_DisconnectFromDatabase : public JobBase  {
-public: 
-	Job_DisconnectFromDatabase();
-	
-	int type() { return JOB_DISCONNECT_FROM_DATABASE; }
+public:
+    Job_DisconnectFromDatabase();
 
-	void run();
-		
-	~Job_DisconnectFromDatabase();
+    int type() {
+        return JOB_DISCONNECT_FROM_DATABASE;
+    }
+
+    void run();
+
+    ~Job_DisconnectFromDatabase();
 };
 
 #endif
