@@ -6,14 +6,16 @@
 #include "jobbase.h"
 
 class Job_DisconnectFromMixxx : public JobBase  {
-public: 
-	Job_DisconnectFromMixxx();
-	
-	int type() { return JOB_DISCONNECT_FROM_MIXXX; }
+public:
+    Job_DisconnectFromMixxx();
 
-	void run();
-		
-	~Job_DisconnectFromMixxx();
+    int type() {
+        return JOB_DISCONNECT_FROM_MIXXX;
+    }
+
+    void run();
+
+    ~Job_DisconnectFromMixxx();
 };
 
 #endif
