@@ -8,16 +8,18 @@
 
 class Job_ImportPlaylist : public JobBase  {
 public:
-	Job_ImportPlaylist(QString);
+    Job_ImportPlaylist(QString);
 
-    int type() { return JOB_IMPORT_PLAYLIST; }
+    int type() {
+        return JOB_IMPORT_PLAYLIST;
+    }
 
-	void run();
-		
-	~Job_ImportPlaylist();
+    void run();
+
+    ~Job_ImportPlaylist();
 
 private:
-   QString fileName;
+    QString fileName;
 
 };
 #endif
