@@ -23,45 +23,51 @@
 #include "database.h"
 #include "datadispatcher.h"
 
-#ifdef EMBEDDED 
-  #include <mysql.h>
+#ifdef EMBEDDED
+#include <mysql.h>
 #endif
 
 Job_ModifyFavourite::Job_ModifyFavourite(int _id, bool _state)
-  : id(_id), state(_state)
-{}
+: id(_id), state(_state) {}
 
-void Job_ModifyFavourite::run()
-{
-  int error;
+void Job_ModifyFavourite::run() {
+    int error;
 
-  if (verbose==8) qWarning( "    >run() tread:%p type:%s HANDLE:%p", this, JOB_CODE[type()], currentThread() );
+    if (verbose==8)
+        qWarning( "    >run() tread:%p type:%s HANDLE:%p", this, JOB_CODE[type()], currentThread() );
 
-#ifdef EMBEDDED 
-  mysql_thread_init(); 
-#endif
-  database->lock();
-  app->lock();
+    #ifdef EMBEDDED
 
-  database->modifyFavouriteArtist(id, state);
+    mysql_thread_init();
+    #endif
 
-  datadispatcher->eventNewFavouritesBasis(database->getFavouritesBasis());
+    database->lock()
+    ;
+    app->lock()
+    ;
 
-  error = database->getError();
+    database->modifyFavouriteArtist(id, state);
 
-  app->unlock();
-  database->unlock();
+    datadispatcher->eventNewFavouritesBasis(database->getFavouritesBasis());
 
-  jobman->lock();
-  jobman->jobDone(this);
-  jobman->unlock();
-#ifdef EMBEDDED 
-  mysql_thread_end(); 
-#endif
+    error = database->getError();
 
-  if (verbose==8) qWarning( "    >exit() thread:%p type:%s HANDLE: %p", this, JOB_CODE[type()], currentThread() );
+    app->unlock();
+    database->unlock();
 
-  exit();
+    jobman->lock()
+    ;
+    jobman->jobDone(this);
+    jobman->unlock();
+    #ifdef EMBEDDED
+
+    mysql_thread_end();
+    #endif
+
+    if (verbose==8)
+        qWarning( "    >exit() thread:%p type:%s HANDLE: %p", this, JOB_CODE[type()], currentThread() );
+
+    exit();
 }
 
 Job_ModifyFavourite::~Job_ModifyFavourite() {}
