@@ -24,17 +24,19 @@
 
 class Job_ModifyFavourite : public JobBase  {
 public:
-	Job_ModifyFavourite(int _id, bool _state);
-	
-	int type() { return JOB_MODIFY_FAVOURITE; }
+    Job_ModifyFavourite(int _id, bool _state);
 
-	void run();
-		
-	~Job_ModifyFavourite();
+    int type() {
+        return JOB_MODIFY_FAVOURITE;
+    }
+
+    void run();
+
+    ~Job_ModifyFavourite();
 
 private:
-	int id;
-	bool state;
+    int id;
+    bool state;
 };
 
 #endif
