@@ -25,17 +25,21 @@
 class Job_PlayAlbum : public JobBase  {
 public:
 
-  Job_PlayAlbum(int type, QString data, QString data2 );
-	
-  void run();
+    Job_PlayAlbum(int type, QString data, QString data2 );
 
-  int type() { return JOB_PLAYALBUM; }
-		
-  ~Job_PlayAlbum() {;}
+    void run();
+
+    int type() {
+        return JOB_PLAYALBUM;
+    }
+
+    ~Job_PlayAlbum() {
+        ;
+    }
 
 private:
-  int querytype;
-  QString querydata,querydata2;
+    int querytype;
+    QString querydata,querydata2;
 };
 
 #endif
