@@ -23,22 +23,24 @@
 #include "jobbase.h"
 
 class Job_QueryDatabase : public JobBase  {
-public: 
-	Job_QueryDatabase(int, int=0);
-	Job_QueryDatabase(int, QString, QString);
-	Job_QueryDatabase(int, QString, bool, bool, bool, bool, bool, bool);
-	
-	int type() { return JOB_QUERY_DATABASE; }
+public:
+    Job_QueryDatabase(int, int=0);
+    Job_QueryDatabase(int, QString, QString);
+    Job_QueryDatabase(int, QString, bool, bool, bool, bool, bool, bool);
 
-	void run();
-		
-	~Job_QueryDatabase();
+    int type() {
+        return JOB_QUERY_DATABASE;
+    }
+
+    void run();
+
+    ~Job_QueryDatabase();
 
 private:
-	int querytype, queryID;
-	QString	querydata;
-	QString	querydata2;
-	bool 	byFilename, byArtist, byTitle, byAlbum, byComment, byNotes;
+    int querytype, queryID;
+    QString querydata;
+    QString querydata2;
+    bool    byFilename, byArtist, byTitle, byAlbum, byComment, byNotes;
 };
 
 #endif
