@@ -4,7 +4,7 @@
     begin                : Wed May 9 2001
     copyright            : (C) 2001 by Holger Sattel
     email                : hsattel@rumms.uni-mannheim.de
-
+ 
     Contributed by Tim Lee ;-)
  ***************************************************************************/
 
@@ -27,50 +27,56 @@
 
 #include <iostream>
 
-#ifdef EMBEDDED 
-  #include <mysql.h>
+#ifdef EMBEDDED
+#include <mysql.h>
 #endif
 
 Job_QueryPlaylist_Tracks::Job_QueryPlaylist_Tracks(int _id)
-  : id(_id)
-{}
+: id(_id) {}
 
-void Job_QueryPlaylist_Tracks::run()
-{
-  int error;
+void Job_QueryPlaylist_Tracks::run() {
+    int error;
 
-  if (verbose==8) qWarning( "    >run() tread:%p type:%s HANDLE:%p", this, JOB_CODE[type()], currentThread() );
+    if (verbose==8)
+        qWarning( "    >run() tread:%p type:%s HANDLE:%p", this, JOB_CODE[type()], currentThread() );
 
-  QList<PLAYLIST_TRACK> *list;
+    QList<PLAYLIST_TRACK> *list;
 
-#ifdef EMBEDDED 
-  mysql_thread_init(); 
-#endif
-  database->lock();
+    #ifdef EMBEDDED
 
-  list = database->getPlaylistTracksBasis(id);
-  error = database->getError();
+    mysql_thread_init();
+    #endif
 
-  database->unlock();
+    database->lock()
+    ;
 
-  if(!error) {
-    app->lock();
+    list = database->getPlaylistTracksBasis(id);
+    error = database->getError();
 
-    datadispatcher->eventNewPlaylistTracksBasis(list, id);
+    database->unlock();
 
-    app->unlock();
-  }
+    if(!error) {
+        app->lock()
+        ;
 
-  jobman->lock();
-  jobman->jobDone(this);
-  jobman->unlock();
-#ifdef EMBEDDED 
-  mysql_thread_end(); 
-#endif
+        datadispatcher->eventNewPlaylistTracksBasis(list, id);
 
-  if (verbose==8) qWarning( "    >exit() thread:%p type:%s HANDLE: %p", this, JOB_CODE[type()], currentThread() );
+        app->unlock();
+    }
 
-  exit();
+    jobman->lock()
+    ;
+    jobman->jobDone(this);
+    jobman->unlock();
+    #ifdef EMBEDDED
+
+    mysql_thread_end();
+    #endif
+
+    if (verbose==8)
+        qWarning( "    >exit() thread:%p type:%s HANDLE: %p", this, JOB_CODE[type()], currentThread() );
+
+    exit();
 }
 
 Job_QueryPlaylist_Tracks::~Job_QueryPlaylist_Tracks() {}
