@@ -4,7 +4,7 @@
     begin                : Wed May 9 2001
     copyright            : (C) 2001 by Holger Sattel
     email                : hsattel@rumms.uni-mannheim.de
-
+ 
     Contributed by Tim Lee ;-)
  ***************************************************************************/
 
@@ -26,16 +26,18 @@
 
 class Job_QueryPlaylist_Tracks : public JobBase  {
 public:
-	Job_QueryPlaylist_Tracks(int _id);
-	
-	int type() { return JOB_QUERY_PLAYLIST_TRACKS; }
+    Job_QueryPlaylist_Tracks(int _id);
 
-	void run();
-		
-	~Job_QueryPlaylist_Tracks();
+    int type() {
+        return JOB_QUERY_PLAYLIST_TRACKS;
+    }
+
+    void run();
+
+    ~Job_QueryPlaylist_Tracks();
 
 private:
-	int id;
+    int id;
 };
 
 #endif
