@@ -23,17 +23,19 @@
 #include "jobbase.h"
 
 class Job_RemoveCustomQuery : public JobBase  {
- public: 
-  Job_RemoveCustomQuery(QString _name);
-  
-  int type() { return JOB_REMOVE_CUSTOM_QUERY; }
-  
-  void run();
-  
-  ~Job_RemoveCustomQuery();
+public:
+    Job_RemoveCustomQuery(QString _name);
 
- private:
-  QString name;
+    int type() {
+        return JOB_REMOVE_CUSTOM_QUERY;
+    }
+
+    void run();
+
+    ~Job_RemoveCustomQuery();
+
+private:
+    QString name;
 };
 
 #endif
