@@ -24,17 +24,19 @@
 #include "jobbase.h"
 
 class Job_RenameMedium : public JobBase  {
- public: 
-  Job_RenameMedium(MEDIUM *_medium);
-  
-  int type() { return JOB_RENAME_MEDIUM; }
-  
-  void run();
-  
-  ~Job_RenameMedium();
+public:
+    Job_RenameMedium(MEDIUM *_medium);
 
- private:
-  MEDIUM *medium;
+    int type() {
+        return JOB_RENAME_MEDIUM;
+    }
+
+    void run();
+
+    ~Job_RenameMedium();
+
+private:
+    MEDIUM *medium;
 };
 
 #endif
