@@ -23,18 +23,20 @@
 #include "jobbase.h"
 
 class Job_StoreCustomQuery : public JobBase  {
- public: 
-  Job_StoreCustomQuery(QString _name, QString _query);
-  
-  int type() { return JOB_STORE_CUSTOM_QUERY; }
-  
-  void run();
-  
-  ~Job_StoreCustomQuery();
+public:
+    Job_StoreCustomQuery(QString _name, QString _query);
 
- private:
-  QString name;
-  QString query;
+    int type() {
+        return JOB_STORE_CUSTOM_QUERY;
+    }
+
+    void run();
+
+    ~Job_StoreCustomQuery();
+
+private:
+    QString name;
+    QString query;
 };
 
 #endif
