@@ -40,27 +40,29 @@
 #include "jobbasetagmanipulation.h"
 
 class Job_SynchronizeWithDatabase : public JobBaseTagManipulation  {
- public: 
-  Job_SynchronizeWithDatabase(int _modus, int _parameter = NO_PARAMETER);
-  Job_SynchronizeWithDatabase(LVI_CDDrive *_drive, int _modus, int _parameter = NO_PARAMETER);
-  Job_SynchronizeWithDatabase(LVI_SMBShare *_share, int _modus, int _parameter = NO_PARAMETER);
-  Job_SynchronizeWithDatabase(LVI_NFSExport *_Export, int _modus, int _parameter = NO_PARAMETER);
-  
-  int type() { return JOB_SYNCHRONIZE_WITH_DATABASE; }
-  
-  int getMediumID();
-  
-  void run();
-  
-  ~Job_SynchronizeWithDatabase();
-  
- private:
-  int mediumType;
-  int modus;
-  int parameter;
-  LVI_CDDrive *drive;
-  LVI_SMBShare *share;
-  LVI_NFSExport *Export;
+public:
+    Job_SynchronizeWithDatabase(int _modus, int _parameter = NO_PARAMETER);
+    Job_SynchronizeWithDatabase(LVI_CDDrive *_drive, int _modus, int _parameter = NO_PARAMETER);
+    Job_SynchronizeWithDatabase(LVI_SMBShare *_share, int _modus, int _parameter = NO_PARAMETER);
+    Job_SynchronizeWithDatabase(LVI_NFSExport *_Export, int _modus, int _parameter = NO_PARAMETER);
+
+    int type() {
+        return JOB_SYNCHRONIZE_WITH_DATABASE;
+    }
+
+    int getMediumID();
+
+    void run();
+
+    ~Job_SynchronizeWithDatabase();
+
+private:
+    int mediumType;
+    int modus;
+    int parameter;
+    LVI_CDDrive *drive;
+    LVI_SMBShare *share;
+    LVI_NFSExport *Export;
 };
 
 #endif
