@@ -27,51 +27,58 @@
 #include <qmap.h>
 
 class JobManager {
- public: 
-  JobManager();
-	
-  void addJob(JobBase *job, bool dequeuedMusicextrasJob = false);	
+public:
+    JobManager();
 
-  void jobDone(JobBase *job);
+    void addJob(JobBase *job, bool dequeuedMusicextrasJob = false);
 
-  void incrJobCounter();
-  void decrJobCounter();
-  int getNumberOfJobsRunning();
-  
-  void lock()		{ mutex.lock(); }
-  void unlock()	{ mutex.unlock(); }
-  void setjob_mextras_max( int value)  { job_mextras_max = value; }
-  
-  bool terminateJob(JobBase *job);
-#ifdef HAVE_MEXTRAS
-  void terminateMusicextrasJob();
-#endif /* HAVE_MEXTRAS */
+    void jobDone(JobBase *job);
 
-  ~JobManager();
+    void incrJobCounter();
+    void decrJobCounter();
+    int getNumberOfJobsRunning();
 
- private:
-  void deleteFinishedJobs();
-	
-  bool job_connect_isRunning;
-  bool job_disconnect_isRunning;
-  bool job_connectMixxx_isRunning;
-  bool job_disconnectMixxx_isRunning;
-  bool job_query_isRunning;
-  bool job_modify_isRunning;
-  bool job_generate_isRunning;
-  bool job_extradata_isRunning;
-  int  job_mextras_Running;
-  bool job_playalbum_isRunning;
-  bool job_importplaylist_isRunning;
-  
-  QMap<int, bool>   job_synchronize_isRunning;
-  QPtrQueue<JobBase> job_mextras_queue;
-  QPtrList<JobBase> jobList;
+    void lock()     {
+        mutex.lock();
+    }
+    void unlock()   {
+        mutex.unlock();
+    }
+    void setjob_mextras_max( int value)  {
+        job_mextras_max = value;
+    }
 
-  int  job_mextras_max;
-  int  jobCounter;
-	
-  QMutex	    mutex;
+    bool terminateJob(JobBase *job);
+    #ifdef HAVE_MEXTRAS
+
+    void terminateMusicextrasJob();
+    #endif /* HAVE_MEXTRAS */
+
+    ~JobManager();
+
+private:
+    void deleteFinishedJobs();
+
+    bool job_connect_isRunning;
+    bool job_disconnect_isRunning;
+    bool job_connectMixxx_isRunning;
+    bool job_disconnectMixxx_isRunning;
+    bool job_query_isRunning;
+    bool job_modify_isRunning;
+    bool job_generate_isRunning;
+    bool job_extradata_isRunning;
+    int  job_mextras_Running;
+    bool job_playalbum_isRunning;
+    bool job_importplaylist_isRunning;
+
+    QMap<int, bool>   job_synchronize_isRunning;
+    QPtrQueue<JobBase> job_mextras_queue;
+    QPtrList<JobBase> jobList;
+
+    int  job_mextras_max;
+    int  jobCounter;
+
+    QMutex      mutex;
 };
 
 #endif
