@@ -20,48 +20,43 @@
 #include "pixmapcache.h"
 
 LVI_CDDrive::LVI_CDDrive(QListView *parent, int _driveID, QString _path, QString _device, int _isAutoMounted)
-	: QListViewItem(parent), driveID(_driveID), isAutoMounted(_isAutoMounted), path(_path), device(_device) 
-{
-	name.sprintf(_("CDROM %d"), driveID);
-	applyUnmount();
-	isLocked = false;
-	isKnown = false;
+: QListViewItem(parent), driveID(_driveID), isAutoMounted(_isAutoMounted), path(_path), device(_device) {
+    name.sprintf(_("CDROM %d"), driveID);
+    applyUnmount();
+    isLocked = false;
+    isKnown = false;
 }
-	
-void LVI_CDDrive::lock(QString comment)
-{
-	isLocked = true;
-	setText(0, name + " [" + comment + "...]");
+
+void LVI_CDDrive::lock(QString comment) {
+    isLocked = true;
+    setText(0, name + " [" + comment + "...]");
 }
-	
-void LVI_CDDrive::unlock()
-{
-	isLocked = false;
-	setText(0, name + " [" + label + "]");
+
+void LVI_CDDrive::unlock() {
+    isLocked = false;
+    setText(0, name + " [" + label + "]");
 }
-	
-void LVI_CDDrive::applyMount(unsigned checksum)
-{
-	isMounted = true;
-	this->checksum = checksum;
-	setPixmap(0, pixmapcache->get("lvi_cdrom.png"));
+
+void LVI_CDDrive::applyMount(unsigned checksum) {
+    isMounted = true;
+    this->checksum = checksum;
+    setPixmap(0, pixmapcache->get
+              ("lvi_cdrom.png"));
 }
 
 
-void LVI_CDDrive::applyUnmount()
-{
-	isMounted = false;
-	cdID      = 0;
-	checksum  = 0;
-	setText(0, name);
-	setPixmap(0, pixmapcache->getFaded("lvi_cdrom.png"));
+void LVI_CDDrive::applyUnmount() {
+    isMounted = false;
+    cdID      = 0;
+    checksum  = 0;
+    setText(0, name);
+    setPixmap(0, pixmapcache->getFaded("lvi_cdrom.png"));
 }
-	
-void LVI_CDDrive::applyInfo(bool isKnown, QString label, int cdID)
-{
-	this->isKnown = isKnown;
-	this->cdID = cdID;
-	this->label = label;
-	setText(0, name + " [" + label + "]");
+
+void LVI_CDDrive::applyInfo(bool isKnown, QString label, int cdID) {
+    this->isKnown = isKnown;
+    this->cdID = cdID;
+    this->label = label;
+    setText(0, name + " [" + label + "]");
 }
 
