@@ -4,7 +4,7 @@
     begin                : Sun May 6 2001
     copyright            : (C) 2001 by Holger Sattel
     email                : hsattel@rumms.uni-mannheim.de
-
+ 
     Contributed by Tim Lee ;-)
  ***************************************************************************/
 
@@ -22,23 +22,28 @@
 #include "pixmapcache.h"
 
 LVI_Playlist::LVI_Playlist(QListView *parent, PLAYLIST *_playlist)
-  : QListViewItem(parent), playlist(_playlist)
-{
-  setText(0,playlist->name);
-  setPixmap(0, pixmapcache->get("lvi_playlist.png"));
+: QListViewItem(parent), playlist(_playlist) {
+    setText(0,playlist->name);
+    setPixmap(0, pixmapcache->get
+              ("lvi_playlist.png"));
 }
 
-int LVI_Playlist::getID() { return playlist->id; }
-QString LVI_Playlist::getName() { return playlist->name; }
+int LVI_Playlist::getID() {
+    return playlist->id;
+}
+QString LVI_Playlist::getName() {
+    return playlist->name;
+}
 
 void LVI_Playlist::setName(QString newname) {
-	playlist->name = newname;
-	setText(0,newname);	
+    playlist->name = newname;
+    setText(0,newname);
 }
 
-QString LVI_Playlist::key() { return playlist->name.lower(); }
+QString LVI_Playlist::key() {
+    return playlist->name.lower();
+}
 
-LVI_Playlist::~LVI_Playlist()
-{
-  delete playlist;
+LVI_Playlist::~LVI_Playlist() {
+    delete playlist;
 }
