@@ -20,48 +20,49 @@
 #include "pixmapcache.h"
 
 LVI_SMBShare::LVI_SMBShare(QListView *parent, int _shareID, QString _path, QString _share)
-  : QListViewItem(parent), shareID(_shareID), path(_path), share(_share)
-{
-  device = share;
+: QListViewItem(parent), shareID(_shareID), path(_path), share(_share) {
+    device = share;
 
-  share.replace(0, 2, "");
-  QString machine = share; machine.truncate(share.find("/"));
-  QString sharename = share; sharename.replace(0, machine.length()+1, "");
+    share.replace(0, 2, "");
+    QString machine = share;
+    machine.truncate(share.find("/"));
+    QString sharename = share;
+    sharename.replace(0, machine.length()+1, "");
 
-  label = QString(machine.upper() + ": " + sharename.upper());
-  isLocked = false;
-  applyUnmount();
-  applyInfo(-1);
-}
-  
-void LVI_SMBShare::lock(QString comment)
-{
-  isLocked = true;
-  setText(0, label + " [" + comment + "...]");
+    label = QString(machine.upper() + ": " + sharename.upper());
+    isLocked = false;
+    applyUnmount();
+    applyInfo(-1);
 }
 
-void LVI_SMBShare::unlock()
-{
-  isLocked = false;
-  if(medium != -1) setText(0, label + " [DB]");
-  else setText(0, label);
+void LVI_SMBShare::lock(QString comment) {
+    isLocked = true;
+    setText(0, label + " [" + comment + "...]");
 }
 
-void LVI_SMBShare::applyMount()
-{
-  isMounted = true;
-  setPixmap(0, pixmapcache->get("lvi_smb.png"));
+void LVI_SMBShare::unlock() {
+    isLocked = false;
+    if(medium != -1)
+        setText(0, label + " [DB]");
+    else
+        setText(0, label);
 }
 
-void LVI_SMBShare::applyUnmount()
-{
-  isMounted = false;
-	setPixmap(0, pixmapcache->getFaded("lvi_smb.png"));
+void LVI_SMBShare::applyMount() {
+    isMounted = true;
+    setPixmap(0, pixmapcache->get
+              ("lvi_smb.png"));
 }
-    
-void LVI_SMBShare::applyInfo(int mediumid)
-{
-  medium = mediumid;
-  if(medium != -1) setText(0, label + " [DB]");
-  else setText(0, label);
+
+void LVI_SMBShare::applyUnmount() {
+    isMounted = false;
+    setPixmap(0, pixmapcache->getFaded("lvi_smb.png"));
+}
+
+void LVI_SMBShare::applyInfo(int mediumid) {
+    medium = mediumid;
+    if(medium != -1)
+        setText(0, label + " [DB]");
+    else
+        setText(0, label);
 }
