@@ -14,17 +14,16 @@
 #include <qvaluevector.h>
 #include <musicbrainz/musicbrainz.h>
 
-class MusicBrainzClient
-{
- public:
-  MusicBrainzClient();
-  
-  QValueVector<QMBMetadata> queryServer(const QString path, TRACK *track);
+class MusicBrainzClient {
+public:
+    MusicBrainzClient();
 
-  ~MusicBrainzClient() {}
-  
- private:
-  MusicBrainz *mB;
+    QValueVector<QMBMetadata> queryServer(const QString path, TRACK *track);
+
+    ~MusicBrainzClient() {}
+
+private:
+    MusicBrainz *mB;
 };
 
 #endif /*HAVE_LIBMUSICBRAINZ*/
