@@ -1,17 +1,17 @@
 /*-----------------------------------------------------------------------
 QMBTagger - Qt Based MusicBrainz MP3/OGG/FLAC Tagger
 Copyright (C) 2003,2004 Ewen Cheslack-Postava
-
+ 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; either version 2 of the License, or
 (at your option) any later version.
-
+ 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.
-
+ 
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
@@ -31,15 +31,14 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #include "qmbfile.h"
 #include <qstring.h>
 
-class QMBMP3File : public QMBFile
-{
+class QMBMP3File : public QMBFile {
 public:
-	QMBMP3File();
-//	~QMBMP3File();
+    QMBMP3File();
+    //  ~QMBMP3File();
 
-	virtual int Extract(QString filename);
+    virtual int Extract(QString filename);
 
-	int GetMetadata(QString filename);
+    int GetMetadata(QString filename);
 };
 
 #endif /*HAVE_LIBMUSICBRAINZ*/
