@@ -1,5 +1,5 @@
 /***************************************************************************
-        	    splashscreen.h  -  description
+                splashscreen.h  -  description
                              -------------------
     begin                : Sun Feb 16 2003
     copyright            : (C) 2003 by Paul-henri ferme
@@ -21,8 +21,7 @@
 #include <qpixmap.h>
 #include <qwidget.h>
 
-class SplashScreen : public QWidget
-{
+class SplashScreen : public QWidget {
 public:
     SplashScreen( const QPixmap &pixmap );
 
